﻿using Microsoft.AspNetCore.Mvc;
using SPS.Client.Api.Exceptions;
using SPS.Client.IoC;

namespace SpsClientMvcCore.Controllers
{
    public class HomeController : Controller
    {
        private readonly NemIDService nemIDService;
        public HomeController(NemIDService nemIDService)
        {
            this.nemIDService = nemIDService;
        }

        public ActionResult Index()
        {
            ViewBag.Maintitle = "Welcome";
            return View();
        }

        /// <summary>
        /// Handles the SPS.Client response. Alternatively, use a try/catch(ValidationException)
        /// The new NemIDFlowValidator().Validate(result) call throws a SPS.Client.Api.Exceptions.ValidationException if not SUCCESS.
        /// </summary>
        /// <param name="result"></param>
        /// <returns></returns>
        public ActionResult HandleBackendResponse(string result)
        {
            try
            {
                var nemidValidationResult = nemIDService.GetFlowValidator().Validate(result);
                return View("~/Views/ViewResult/ShowResult.cshtml", nemidValidationResult);
            }
            catch (ValidationException vEx)
            {
                //Log vEx.ErrorMessage - this is intended for you logs
                //vEx.FlowErrorCode is the NemID ErrorCode
                //vEx.UserMessage can be shown to the user
                return View("~/Views/Error/OnValidationException.cshtml", vEx);
            }

        }
    }
}
