﻿using System.IO;
using Microsoft.AspNetCore.Hosting;
using Microsoft.AspNetCore.Mvc;
using Microsoft.Extensions.Options;
using SpsClientMvcCore.Configuration;
using SPS.Client.Frame;
using SPS.Client.IoC;

namespace SpsClientMvcCore.Controllers
{
    public class KeyfileController : Controller
    {
        private readonly NemIDService nemIDService;
        private readonly DemoSettings settings;
        private readonly IHostingEnvironment env;
        public KeyfileController(NemIDService nemIDService, IOptions<DemoSettings> settings, IHostingEnvironment hostingEnvironment)
        {
            this.nemIDService = nemIDService;
            this.settings = settings.Value;
            env = hostingEnvironment;
        }

        public ActionResult Logon()
        {
            ViewBag.Maintitle = "Keyfile logon";
            UpdateViewBagWithNemIdParameters(nemIDService.GetKeyFileBuilder());
            return View();
        }

        public ActionResult SignPdf()
        {
            ViewBag.Maintitle = "Keyfile Signature (PDF)";
            var frameBuilder = nemIDService.GetFileSignBuilder().SignPdf(System.IO.File.ReadAllBytes(Path.Combine(env.ContentRootPath, settings.SignPdfPath)));
            UpdateViewBagWithNemIdParameters(frameBuilder);
            return View();
        }

        public ActionResult SignText()
        {
            ViewBag.Maintitle = "Keyfile Signature (Text)";
            var messageToBeSigned = "IT-løsning fra Signaturgruppen\nLicens og assistance\n\n\nDer tilbydes kontrakt mellem parterne...";
            UpdateViewBagWithNemIdParameters(nemIDService.GetFileSignBuilder().SignText(messageToBeSigned));

            return View();
        }
        
        private void UpdateViewBagWithNemIdParameters(FrameBuilder frameBuilder)
        {
            ViewBag.NemIdParameterBlock = frameBuilder.GetScript(Url.Action("HandleBackendResponse", "Home"));
            ViewBag.IframeUrl = frameBuilder.FrameUrl;
        }
    }
}