﻿using System.IO;
using Microsoft.AspNetCore.Hosting;
using Microsoft.AspNetCore.Mvc;
using Microsoft.Extensions.Options;
using SpsClientMvcCore.Configuration;
using SPS.Client.Frame;
using SPS.Client.IoC;

namespace SpsClientMvcCore.Controllers
{
    public class NemidController : Controller
    {
        private readonly NemIDService nemIDService;
        private readonly DemoSettings settings;
        private readonly IHostingEnvironment env;
        public NemidController(NemIDService nemIDService, IOptions<DemoSettings> settings, IHostingEnvironment hostingEnvironment)
        {
            this.nemIDService = nemIDService;
            this.settings = settings.Value;
            env = hostingEnvironment;
        }
        public ActionResult Logon()
        {
            ViewBag.Maintitle = "NemID Logon";
            UpdateViewBagWithNemIdParameters(nemIDService.GetLoginBuilder());
            return View();
        }

        public ActionResult LogonUsingJsHandler()
        {
            ViewBag.Maintitle = "NemID Logon";
            UpdateViewBagWithNemIdParametersJsHander(nemIDService.GetLoginBuilder());
            return View();
        }

        public ActionResult SignPdf()
        {
            ViewBag.Maintitle = "NemID Signature (PDF)";
            var frameBuilder = nemIDService.GetSignBuilder()
                .SignPdf(System.IO.File.ReadAllBytes(Path.Combine(env.ContentRootPath, settings.SignPdfPath)));

            UpdateViewBagWithNemIdParameters(frameBuilder);

            return View();
        }

        public ActionResult SignText()
        {
            ViewBag.Maintitle = "NemID Signature (Text)";
            const string messageToBeSigned = "IT-løsning fra Signaturgruppen\nLicens og assistance\n\n\nDer tilbydes kontrakt mellem parterne...";
            UpdateViewBagWithNemIdParameters(nemIDService.GetSignBuilder().SignText(messageToBeSigned));

            return View();
        }

        private void UpdateViewBagWithNemIdParameters(FrameBuilder frameBuilder)
        {
            ViewBag.NemIdParameterBlock = frameBuilder.GetScript(Url.Action("HandleBackendResponse", "Home"));
            ViewBag.IframeUrl = frameBuilder.FrameUrl;
        }

        private void UpdateViewBagWithNemIdParametersJsHander(FrameBuilder frameBuilder)
        {
            ViewBag.NemIdParameterBlock = frameBuilder.GetScriptForJsCallback("nemidResultHandler");
            ViewBag.IframeUrl = frameBuilder.FrameUrl;
        }
    }
}