﻿using Microsoft.AspNetCore.Builder;
using Microsoft.AspNetCore.Hosting;
using Microsoft.AspNetCore.Http;
using Microsoft.Extensions.Configuration;
using Microsoft.Extensions.DependencyInjection;
using SpsClientMvcCore.Configuration;
using SpsClientMvcCore.IoC;
using SPS.Client.IoC;

namespace SpsClientMvcCore
{
    public class Startup
    {
        public Startup(IConfiguration configuration)
        {
            Configuration = configuration;
        }

        public IConfiguration Configuration { get; }

        // This method gets called by the runtime. Use this method to add services to the container.
        public void ConfigureServices(IServiceCollection services)
        {
            services.AddMvc();

            services.Configure<DemoSettings>(Configuration.GetSection("DemoSettings"));
            
            services.AddDistributedMemoryCache(); // Adds a default in-memory implementation of IDistributedCache
            services.AddSession(); // Use sessions
            // https://github.com/aspnet/Hosting/issues/793
            services.AddSingleton<IHttpContextAccessor, HttpContextAccessor>();

            AddSpsClientServices(services);
        }

        private void AddSpsClientServices(IServiceCollection services)
        {
            // Create your own implementation of SpsConfigurationService to facilitate load of the SPS.Client JSON configuration
            // SpsConfiguration(string JSON); is used to construct the return type - just find your own way of loading the JSON configuration
            // You will receive a specific JSON for production directly from Signaturgruppen. The embedded JSON in this project
            // 
            services.Configure<SpsAppSettings>(Configuration.GetSection("SpsClient"));
            services.AddSingleton<SpsClientConfigurationService, SpsConfigurationImpl>();
            services.AddTransient<NemIDService, NemIDServiceImpl>();
        }

        // This method gets called by the runtime. Use this method to configure the HTTP request pipeline.
        public void Configure(IApplicationBuilder app, IHostingEnvironment env)
        {
            if (env.IsDevelopment())
            {
                app.UseDeveloperExceptionPage();
                app.UseBrowserLink();
            }
            else
            {
                app.UseExceptionHandler("/Home/Error");
            }

            app.UseStaticFiles();
            app.UseSession(); // <<---- Must be called to activate SESSIONS
            app.UseMvc(routes =>
            {
                routes.MapRoute(
                    name: "default",
                    template: "{controller=Home}/{action=Index}/{id?}");
            });
        }
    }
}
